@@ -37,15 +37,15 @@ class VaultConfig(DBConfiguration):
         """Return the vault user passphrase"""
         return self._passphrase
 
+    @property
+    def database(self) -> str:
+        return self.unlocked_vault_file
+
     @property
     def vault_file(self) -> str:
         """Return the locked vault database filename"""
         return self._vault_file
 
-    @property
-    def db_file(self) -> str:
-        return self.unlocked_vault_file
-
     @property
     def unlocked_vault_file(self) -> str:
         """Return the locked vault database filename"""
